==> phpgroupware-0.9.16.011.tbz: www/data-dist/phpgroupware/phpsysinfo/includes/lang/he.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: he.php,v 1.1.2.1 2003/11/01 22:10:21 skwashd Exp $
$charset                = 'windows-1255';
$text_dir               = 'rtl';
$text['title']          = '  ';

$text['vitals']         = ' ';
$text['hostname']       = ' ';
$text['ip']             = ' IP';
$text['kversion']       = ' ';
$text['uptime']         = '  ';
$text['users']          = ' ';
$text['loadavg']        = ' ';

$text['hardware']       = ' ';
$text['numcpu']         = '';
$text['cpumodel']       = '';
$text['mhz']            = ' MHz';
$text['cache']          = '  ';
$text['bogomips']       = ' bogomips';
$text['pci']            = ' PCI';
$text['ide']            = ' IDE';
$text['scsi']           = ' SCSI';

$text['netusage']       = '';
$text['device']         = '';
$text['received']       = '';
$text['sent']           = '';
$text['errors']         = '/';

$text['connections']    = '  ';

$text['memusage']       = ' ';
$text['phymem']         = ' ';
$text['swap']           = ' swap';

$text['fs']             = '  ';
$text['mount']          = '';
$text['partition']      = '';

$text['percent']        = ' ';
$text['type']           = '';
$text['free']           = '';
$text['used']           = '';
$text['size']           = '';
$text['totals']         = '"';

$text['kb']             = ' ';
$text['mb']             = '';
$text['gb']             = '';

$text['none']           = '';

$text['capacity']       = ''; 

$text['template']       = '';
$text['language']       = '';
$text['submit']         = '';
$text['created']        = ' "';

$text['days']           = '';
$text['hours']          = '';
$text['minutes']        = '';
?>

==> phpgroupware-0.9.16.017.tbz: www/data-dist/phpgroupware/phpsysinfo/includes/lang/he.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: he.php 21052 2010-03-25 22:44:08Z Caeies $
$charset                = 'windows-1255';
$text_dir               = 'rtl';
$text['title']          = '  ';

$text['vitals']         = ' ';
$text['hostname']       = ' ';
$text['ip']             = ' IP';
$text['kversion']       = ' ';
$text['dversion']       = 'Distro Name';
$text['uptime']         = '  ';
$text['users']          = ' ';
$text['loadavg']        = ' ';

$text['hardware']       = ' ';
$text['numcpu']         = '';
$text['cpumodel']       = '';
$text['cpuspeed']       = ' MHz';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = '  ';
$text['bogomips']       = ' bogomips';

$text['pci']            = ' PCI';
$text['ide']            = ' IDE';
$text['scsi']           = ' SCSI';
$text['usb']            = ' USB';

$text['netusage']       = '';
$text['device']         = '';
$text['received']       = '';
$text['sent']           = '';
$text['errors']         = '/';

$text['connections']    = '  ';

$text['memusage']       = ' ';
$text['phymem']         = ' ';
$text['swap']           = ' swap';

$text['fs']             = '  ';
$text['mount']          = '';
$text['partition']      = '';

$text['percent']        = ' ';
$text['type']           = '';
$text['free']           = '';
$text['used']           = '';
$text['size']           = '';
$text['totals']         = '"';

$text['kb']             = ' ';
$text['mb']             = '';
$text['gb']             = '';

$text['none']           = '';

$text['capacity']       = ''; 

$text['template']       = '';
$text['language']       = '';
$text['submit']         = '';
$text['created']        = ' "';
$text['locale']         = 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %I:%M %p';

$text['days']           = '';
$text['hours']          = '';
$text['minutes']        = '';
  
$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degreeC']        = '&deg;C';
$text['degreeF']        = '&deg;F';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']		= 'Kernel + applications';
$text['buffers']	= 'Buffers';
$text['cached']		= 'Cached';

?>
